@@ -1,7 +1,7 @@
-from .magichue import Light
+from .magichue import Light, discover_bulbs
 from .modes import *
 
 
 __author__ = 'namacha'
-__version__ = '0.2.7'
+__version__ = '0.2.8'
 __license__ = 'MIT'
